import numpy as np
import pandas as pd

def Ivan_horse(filename):
	#print(filename)
	import scipy.constants as const
	ds=pd.read_csv(filename,sep='\t',index_col=0)
	ds.index=ds.index.astype(float)
	ds.columns=ds.columns.astype(float)
	#ds.index=ds.index.values/1e8
	#ds.columns=ds.columns.values/1e5
	#ds=ds.apply(lambda x:x*ds.index.values)
	#ds=ds.apply(lambda x:x*ds.columns.values,axis=1)
	#per_photon=const.h*const.c/(485e-9)
	#ds=	ds*per_photon
	ds.index.name='Fluence in Photons/cm2 s'
	ds.columns.name='Repetitions rate in Hz'
	ds.sort_index(inplace=True)
	ds.sort_index(inplace=True,axis=1)
	return ds.T,'PLQY'

def streak_Lund(filename):
    code=filename.split('-')
    ds=pd.read_csv(filename,sep='\t',header=None)
    n_times=len(ds.index.values)
    n_waves=len(ds.columns)
    times={'t6':np.linspace(0,2000,n_times),
           't5':np.linspace(0,1000,n_times),
           't4':np.linspace(0,500,n_times),
           't3':np.linspace(0,200,n_times),
           't2':np.linspace(0,100,n_times),
           't1':np.linspace(0,50,n_times)}
    for i in [4,3,2,5]:
        try:
            times=times[code[i]]
            break
        except:
            pass
    for i in [6,5,7,8]:
        if code[i][0]=='w':
            center=code[i][1:]
            waves=np.linspace(float(center)-60,float(center)+75,n_waves)
            break
        else:
            continue
    ds.index=times
    ds.index=ds.index.astype(float)
    ds.columns=waves
    ds.columns=ds.columns.astype(float)
    ds.index.name='Time in ps'
    ds.columns.name='Wavelength in nm'
    return ds,'emission intensity'
	
def Amine_func(filename):
	df=pd.read_csv(filename,sep='\t',header=None)
	wavelength=pd.Series(np.linspace(343.33,656.03,512))
	time=pd.Series(np.linspace(0,50.500,512))
	df.columns=wavelength
	df.index=time
	df.index=df.index.astype(float)
	df.columns=df.columns.astype(float)
	df.index.name='Time in ns'
	df.columns.name='Wavelength in nm'
	return df,'differential absorption','ns'


	c=np.zeros((len(times),3),dtype='float') 						#creation of matrix that will hold the concentrations
	g=gauss(times,sigma=pardf['resolution']/FWHM,mu=pardf['t0']) 	#creating the gaussian pulse that will "excite" our sample
	sub_steps=10 													#defining how many extra steps will be taken between the main time_points
	for i in range(1,len(times)):									#iterate over all timepoints
		dc=np.zeros((3,1),dtype='float')							#the initial change for each concentration, the "3" is representative of how many changes there will be
		dt=(times[i]-times[i-1])/(sub_steps)						# as we are taking smaller steps the time intervals need to be adapted
		c_temp=c[i-1,:]												#temporary matrix holding the changes (needed as we have sub steps and need to check for zero in the end)
		for j in range(int(sub_steps)):
			dc[0]=-pardf['k0']*dt*c_temp[0]-pardf['k2']*dt*c_temp[0]+g[i]*dt					
			dc[1]=pardf['k0']*dt*c_temp[0]-pardf['k1']*dt*c_temp[1]
			dc[2]=pardf['k1']*dt*c_temp[1]+pardf['k2']*dt*c_temp[0]
			for b in range(c.shape[1]):
				c_temp[b] =np.nanmax([(c_temp[b]+dc[b]),0.])		#check that nothing will be below 0 (concentrations)
		c[i,:] =c_temp												#store the temporary concentrations into the main matrix
	c=pandas.DataFrame(c,index=times)								#write back the right indexes
	c.index.name='time'												#and give it a name
	c.columns=['A','B','Inf']	